==> core-0.1.42.tgz: package/esm/drivers/MouseMoveDriver.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { EventDriver } from '@designable/shared';
import { MouseMoveEvent } from '../events';
var MouseMoveDriver = (function (_super) {
    __extends(MouseMoveDriver, _super);
    function MouseMoveDriver() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.request = null;
        _this.onMouseMove = function (e) {
            _this.request = requestAnimationFrame(function () {
                cancelAnimationFrame(_this.request);
                _this.dispatch(new MouseMoveEvent({
                    clientX: e.clientX,
                    clientY: e.clientY,
                    pageX: e.pageX,
                    pageY: e.pageY,
                    target: e.target,
                    view: e.view,
                }));
            });
        };
        return _this;
    }
    MouseMoveDriver.prototype.attach = function () {
        this.addEventListener('mousemove', this.onMouseMove, {
            once: true,
        });
    };
    MouseMoveDriver.prototype.detach = function () {
        this.removeEventListener('mouseover', this.onMouseMove, {
            once: true,
        });
    };
    return MouseMoveDriver;
}(EventDriver));
export { MouseMoveDriver };

==> core-0.5.3.tgz: package/esm/drivers/MouseMoveDriver.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { EventDriver } from '@designable/shared';
import { MouseMoveEvent } from '../events';
var MouseMoveDriver = /** @class */ (function (_super) {
    __extends(MouseMoveDriver, _super);
    function MouseMoveDriver() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.request = null;
        _this.onMouseMove = function (e) {
            _this.request = requestAnimationFrame(function () {
                cancelAnimationFrame(_this.request);
                _this.dispatch(new MouseMoveEvent({
                    clientX: e.clientX,
                    clientY: e.clientY,
                    pageX: e.pageX,
                    pageY: e.pageY,
                    target: e.target,
                    view: e.view,
                }));
            });
        };
        return _this;
    }
    MouseMoveDriver.prototype.attach = function () {
        this.addEventListener('mousemove', this.onMouseMove, {
            once: true,
        });
    };
    MouseMoveDriver.prototype.detach = function () {
        this.removeEventListener('mouseover', this.onMouseMove, {
            once: true,
        });
    };
    return MouseMoveDriver;
}(EventDriver));
export { MouseMoveDriver };
